@@ -95,7 +95,7 @@ TEST_P(SuperframeTest, TestSuperframeIndexIsOptional) {
   EXPECT_EQ(sf_count_, 1);
 }
 
-VP9_INSTANTIATE_TEST_CASE(
+VP9_INSTANTIATE_TEST_SUITE(
     SuperframeTest,
     ::testing::Combine(::testing::Values(::libvpx_test::kTwoPassGood),
                        ::testing::Values(0)));
