@@ -457,6 +457,7 @@ static void set_rt_speed_feature_framesize_independent(
   sf->cb_pred_filter_search = 0;
   sf->force_smooth_interpol = 0;
   sf->rt_intra_dc_only_low_content = 0;
+  sf->mv.enable_adaptive_subpel_force_stop = 0;
 
   if (speed >= 1) {
     sf->allow_txfm_domain_distortion = 1;
@@ -633,6 +634,7 @@ static void set_rt_speed_feature_framesize_independent(
       sf->use_compound_nonrd_pickmode = 1;
     }
     if (cm->width * cm->height > 1280 * 720) sf->cb_pred_filter_search = 1;
+    if (!cpi->external_resize) sf->use_source_sad = 1;
   }
 
   if (speed >= 6) {
@@ -645,8 +647,6 @@ static void set_rt_speed_feature_framesize_independent(
     sf->mv.reduce_first_step_size = 1;
     sf->skip_encode_sb = 0;
 
-    if (!cpi->external_resize) sf->use_source_sad = 1;
-
     if (sf->use_source_sad) {
       sf->adapt_partition_source_sad = 1;
       sf->adapt_partition_thresh =
@@ -727,7 +727,10 @@ static void set_rt_speed_feature_framesize_independent(
   if (speed >= 8) {
     sf->adaptive_rd_thresh = 4;
     sf->skip_encode_sb = 1;
-    sf->nonrd_keyframe = 1;
+    if (cpi->svc.number_spatial_layers > 1 && !cpi->svc.simulcast_mode)
+      sf->nonrd_keyframe = 0;
+    else
+      sf->nonrd_keyframe = 1;
     if (!cpi->use_svc) cpi->max_copied_frame = 4;
     if (cpi->row_mt && cpi->oxcf.max_threads > 1)
       sf->adaptive_rd_thresh_row_mt = 1;
@@ -786,6 +789,15 @@ static void set_rt_speed_feature_framesize_independent(
     if (cm->width * cm->height >= 640 * 360) sf->variance_part_thresh_mult = 2;
   }
 
+  // Disable split to 8x8 for low-resolution at very high Q.
+  // For variance partition (speed >= 6). Ignore the first few frames
+  // as avg_frame_qindex starts at max_q (worst_quality).
+  if (cm->frame_type != KEY_FRAME && cm->width * cm->height <= 320 * 240 &&
+      sf->partition_search_type == VAR_BASED_PARTITION &&
+      cpi->rc.avg_frame_qindex[INTER_FRAME] > 208 &&
+      cpi->common.current_video_frame > 8)
+    sf->disable_16x16part_nonkey = 1;
+
   if (sf->nonrd_use_ml_partition)
     sf->partition_search_type = ML_BASED_PARTITION;
 
